==> gatsby-theme-backend-1.0.0.tgz: package/src/pages/backend.js <==
import React from "react"
import { Router } from "@reach/router"
import { Link, navigate } from "gatsby"
import ThemeContext from "../context/ThemeContext"
import { IntlProvider, FormattedMessage } from "react-intl"
import ProLayout, { PageContainer, DefaultFooter } from "@ant-design/pro-layout"
import { login, logout, getProfile, isAdministrator } from "../services/auth"
import PrivateRoute from "../components/Backend/PrivateRoute"
import LangSwitcher from "../components/Backend/LangSwitcher"
import BackendPage from "../components/Backend"
import Dashboard from "../components/Backend/Dashboard"
import Pages from "../components/Backend/Pages"
import EditPage from "../components/Backend/Pages/[slug]"
import Posts from "../components/Backend/Posts"
import EditPost from "../components/Backend/Posts/[slug]"
import NewPost from "../components/Backend/Posts/new"
import SettingAccount from "../components/Backend/Settings/Account"
import SettingLanguages from "../components/Backend/Settings/Languages"
import SettingMenus from "../components/Backend/Settings/Menus"
import Deploy from "../components/Backend/Deploy"
import NotFound from "./404"
import JsonBackend from "../settings/backend.json"
import logo from "../../static/images/logo.svg"
import { ConfigProvider, Menu, Dropdown, Avatar } from "antd"
import enUS from "antd/lib/locale/en_US"
import thTH from "antd/lib/locale/th_TH"
import zhCN from "antd/lib/locale/zh_CN"
import enMessages from "../messages/en.json"
import thMessages from "../messages/th.json"
import zhMessages from "../messages/zh.json"
import {
	DownOutlined,
	FacebookFilled,
	DashboardOutlined,
	OrderedListOutlined,
	CloudUploadOutlined,
	SettingOutlined,
	LogoutOutlined,
	UserOutlined,
} from "@ant-design/icons"
import "../theme/backend.less"

const intlMap = {
	enUS,
	thTH,
	zhCN,
}
const messagesMap = {
	enMessages,
	thMessages,
	zhMessages,
}

const Backend = () => {
	let jsonData = null
	if (JsonBackend) {
		jsonData = JsonBackend[0]
	}

	const user = getProfile()
	let rightMenu = null
	let defaultProps = null
	if (user) {
		if (isAdministrator()) {
			rightMenu = (
				<Menu>
					<Menu.Item icon={<SettingOutlined />}>
						<Link to="/backend/settings/account">
							<FormattedMessage id="menu.settings.account" />
						</Link>
					</Menu.Item>
					<Menu.Item icon={<CloudUploadOutlined />}>
						<Link to="/backend/deploy">
							<FormattedMessage id="menu.deploy" />
						</Link>
					</Menu.Item>
					<Menu.Item danger icon={<LogoutOutlined />}>
						<a
							href="#logout"
							onClick={(e) => {
								logout()
								e.preventDefault()
							}}
						>
							<FormattedMessage id="menu.logout" />
						</a>
					</Menu.Item>
				</Menu>
			)
			defaultProps = {
				route: {
					path: "/backend",
					routes: [
						{
							path: "/backend/dashboard",
							name: <FormattedMessage id="menu.dashboard" />,
							icon: <DashboardOutlined />,
						},
						{
							path: "/backend/pages",
							name: <FormattedMessage id="menu.pages" />,
							icon: <OrderedListOutlined />,
							children: [
								{
									path: "/backend/pages/all",
									name: <FormattedMessage id="menu.all.pages" />,
								},
							],
						},
						{
							path: "/backend/posts",
							name: <FormattedMessage id="menu.posts" />,
							icon: <OrderedListOutlined />,
							children: [
								{
									path: "/backend/posts/all",
									name: <FormattedMessage id="menu.all.posts" />,
								},
								{
									path: "/backend/posts/new",
									name: <FormattedMessage id="menu.new.post" />,
								},
							],
						},
						{
							path: "/backend/setting",
							name: <FormattedMessage id="menu.settings" />,
							icon: <SettingOutlined />,
							children: [
								{
									path: "/backend/settings/account",
									name: <FormattedMessage id="menu.settings.account" />,
								},
								{
									path: "/backend/settings/languages",
									name: <FormattedMessage id="menu.settings.languages" />,
								},
								{
									path: "/backend/settings/menus",
									name: <FormattedMessage id="menu.settings.menus" />,
								},
							],
						},
						{
							path: "/backend/deploy",
							name: <FormattedMessage id="menu.deploy" />,
							icon: <CloudUploadOutlined />,
						},
						{
							component: "404",
						},
					],
				},
			}
		} else {
			rightMenu = (
				<Menu>
					<Menu.Item danger icon={<LogoutOutlined />}>
						<a
							href="#logout"
							onClick={(e) => {
								logout()
								e.preventDefault()
							}}
						>
							<FormattedMessage id="menu.logout" />
						</a>
					</Menu.Item>
				</Menu>
			)
			defaultProps = {
				route: {
					path: "/backend",
					routes: [
						{
							path: "/backend/dashboard",
							name: <FormattedMessage id="menu.dashboard" />,
							icon: <DashboardOutlined />,
						},
						{
							path: "/backend/setting",
							name: <FormattedMessage id="menu.settings" />,
							icon: <SettingOutlined />,
							children: [
								{
									path: "/backend/settings/account",
									name: <FormattedMessage id="menu.settings.account" />,
								},
							],
						},
						{
							component: "404",
						},
					],
				},
			}
		}
	} else {
		login()
		return null
	}

	const defaultFooterDom = (
		<DefaultFooter
			copyright={`${new Date().getFullYear()} Deeboon Part., Ltd.`}
			links={[
				{
					key: "Websitecafe",
					title: "Websitecafe",
					href: "https://websitecafe.co/",
					blankTarget: true,
				},
				{
					key: "Facebook",
					title: <FacebookFilled style={{ fontSize: "14px", color: "#000" }} />,
					href: "https://web.facebook.com/websitecafe2003",
					blankTarget: true,
				},
				{
					key: "Deeboon",
					title: "Deeboon",
					href: "https://www.deeboon.co.th/",
					blankTarget: true,
				},
			]}
		/>
	)

	return (
		<ThemeContext.Consumer>
			{({ currentLang, currentLocale, currentMessage }) => (
				<IntlProvider
					locale={currentLocale}
					messages={messagesMap[currentMessage]}
				>
					<ConfigProvider locale={intlMap[currentLang]}>
						<ProLayout
							logo={
								jsonData && jsonData["logo-image"]
									? jsonData["logo-image"]
									: logo
							}
							title={jsonData ? jsonData["logo-text"] : "Deeboon Backend"}
							loading={false}
							siderWidth={jsonData ? jsonData["sider-width"] : 240}
							{...defaultProps}
							onMenuHeaderClick={() => navigate("/")}
							menuItemRender={(menuItemProps, defaultDom) => {
								if (menuItemProps.isUrl || !menuItemProps.path) {
									return defaultDom
								}

								return <Link to={menuItemProps.path}>{defaultDom}</Link>
							}}
							breadcrumbRender={(routers = []) => [
								{
									path: "/",
									breadcrumbName: <FormattedMessage id="menu.home" />,
								},
								...routers,
							]}
							itemRender={(route, params, routes, paths) => {
								const first = routes.indexOf(route) === 0
								return first ? (
									<Link to="/">{route.breadcrumbName}</Link>
								) : (
									<span>{route.breadcrumbName}</span>
								)
							}}
							footerRender={() => defaultFooterDom}
							rightContentRender={() => {
								return user ? (
									<>
										<Dropdown overlay={rightMenu}>
											<a
												className="userLinkWrapper"
												href="#none"
												onClick={(e) => e.preventDefault()}
											>
												<Avatar
													size={24}
													icon={<UserOutlined />}
													style={{
														color: "#f56a00",
														backgroundColor: "#fde3cf",
													}}
												/>
												<span className="nameOrEmail">
													{user.user_metadata.full_name
														? user.user_metadata.full_name
														: user.email}
												</span>
												<DownOutlined />
											</a>
										</Dropdown>
										<LangSwitcher />
									</>
								) : (
									<Avatar size={24}>?</Avatar>
								)
							}}
						>
							<PageContainer>
								<Router>
									<PrivateRoute
										path="/backend/dashboard"
										component={Dashboard}
									/>
									<PrivateRoute path="/backend/pages" component={Pages} />
									<PrivateRoute path="/backend/pages/all" component={Pages} />
									<PrivateRoute
										path="/backend/pages/:slug"
										component={EditPage}
									/>
									<PrivateRoute path="/backend/posts" component={Posts} />
									<PrivateRoute path="/backend/posts/all" component={Posts} />
									<PrivateRoute
										path="/backend/posts/:slug"
										component={EditPost}
									/>
									<PrivateRoute path="/backend/posts/new" component={NewPost} />
									<PrivateRoute
										path="/backend/settings/account"
										component={SettingAccount}
									/>
									<PrivateRoute
										path="/backend/settings/languages"
										component={SettingLanguages}
									/>
									<PrivateRoute
										path="/backend/settings/menus"
										component={SettingMenus}
									/>
									<PrivateRoute path="/backend/deploy" component={Deploy} />
									<BackendPage path="/backend" />
									<NotFound path="*" />
								</Router>
							</PageContainer>
						</ProLayout>
					</ConfigProvider>
				</IntlProvider>
			)}
		</ThemeContext.Consumer>
	)
}

export default Backend

==> gatsby-theme-backend-1.0.1.tgz: package/src/pages/backend.js <==
import React from "react"
import { Router } from "@reach/router"
import { Link, navigate } from "gatsby"
import ThemeContext from "../context/ThemeContext"
import { IntlProvider, FormattedMessage } from "react-intl"
import ProLayout, { PageContainer, DefaultFooter } from "@ant-design/pro-layout"
import { login, logout, getProfile, isAdministrator } from "../services/auth"
import PrivateRoute from "../components/Backend/PrivateRoute"
import LangSwitcher from "../components/Backend/LangSwitcher"
import BackendPage from "../components/Backend"
import Dashboard from "../components/Backend/Dashboard"
import Pages from "../components/Backend/Pages"
import EditPage from "../components/Backend/Pages/[slug]"
import Posts from "../components/Backend/Posts"
import EditPost from "../components/Backend/Posts/[slug]"
import NewPost from "../components/Backend/Posts/new"
import SettingAccount from "../components/Backend/Settings/Account"
import SettingLanguages from "../components/Backend/Settings/Languages"
import SettingMenus from "../components/Backend/Settings/Menus"
import Deploy from "../components/Backend/Deploy"
import NotFound from "./404"
import JsonBackend from "../settings/backend.json"
import logo from "../../static/images/logo.svg"
import { ConfigProvider, Menu, Dropdown, Avatar } from "antd"
import enUS from "antd/lib/locale/en_US"
import thTH from "antd/lib/locale/th_TH"
import zhCN from "antd/lib/locale/zh_CN"
import enMessages from "../messages/en.json"
import thMessages from "../messages/th.json"
import zhMessages from "../messages/zh.json"
import {
	DownOutlined,
	FacebookFilled,
	DashboardOutlined,
	OrderedListOutlined,
	CloudUploadOutlined,
	SettingOutlined,
	LogoutOutlined,
	UserOutlined,
	GithubOutlined,
	GlobalOutlined,
} from "@ant-design/icons"
import "../theme/backend.less"

const intlMap = {
	enUS,
	thTH,
	zhCN,
}
const messagesMap = {
	enMessages,
	thMessages,
	zhMessages,
}

const Backend = () => {
	let jsonData = null
	if (JsonBackend) {
		jsonData = JsonBackend[0]
	}

	const user = getProfile()
	let rightMenu = null
	let defaultProps = null
	if (user) {
		if (isAdministrator()) {
			rightMenu = (
				<Menu>
					<Menu.Item icon={<SettingOutlined />}>
						<Link to="/backend/settings/account">
							<FormattedMessage id="menu.settings.account" />
						</Link>
					</Menu.Item>
					<Menu.Item icon={<CloudUploadOutlined />}>
						<Link to="/backend/deploy">
							<FormattedMessage id="menu.deploy" />
						</Link>
					</Menu.Item>
					<Menu.Item danger icon={<LogoutOutlined />}>
						<a
							href="#logout"
							onClick={(e) => {
								logout()
								e.preventDefault()
							}}
						>
							<FormattedMessage id="menu.logout" />
						</a>
					</Menu.Item>
				</Menu>
			)
			defaultProps = {
				route: {
					path: "/backend",
					routes: [
						{
							path: "/backend/dashboard",
							name: <FormattedMessage id="menu.dashboard" />,
							icon: <DashboardOutlined />,
						},
						{
							path: "/backend/pages",
							name: <FormattedMessage id="menu.pages" />,
							icon: <OrderedListOutlined />,
							children: [
								{
									path: "/backend/pages/all",
									name: <FormattedMessage id="menu.all.pages" />,
								},
							],
						},
						{
							path: "/backend/posts",
							name: <FormattedMessage id="menu.posts" />,
							icon: <OrderedListOutlined />,
							children: [
								{
									path: "/backend/posts/all",
									name: <FormattedMessage id="menu.all.posts" />,
								},
								{
									path: "/backend/posts/new",
									name: <FormattedMessage id="menu.new.post" />,
								},
							],
						},
						{
							path: "/backend/setting",
							name: <FormattedMessage id="menu.settings" />,
							icon: <SettingOutlined />,
							children: [
								{
									path: "/backend/settings/account",
									name: <FormattedMessage id="menu.settings.account" />,
								},
								{
									path: "/backend/settings/languages",
									name: <FormattedMessage id="menu.settings.languages" />,
								},
								{
									path: "/backend/settings/menus",
									name: <FormattedMessage id="menu.settings.menus" />,
								},
							],
						},
						{
							path: "/backend/deploy",
							name: <FormattedMessage id="menu.deploy" />,
							icon: <CloudUploadOutlined />,
						},
						{
							component: "404",
						},
					],
				},
			}
		} else {
			rightMenu = (
				<Menu>
					<Menu.Item danger icon={<LogoutOutlined />}>
						<a
							href="#logout"
							onClick={(e) => {
								logout()
								e.preventDefault()
							}}
						>
							<FormattedMessage id="menu.logout" />
						</a>
					</Menu.Item>
				</Menu>
			)
			defaultProps = {
				route: {
					path: "/backend",
					routes: [
						{
							path: "/backend/dashboard",
							name: <FormattedMessage id="menu.dashboard" />,
							icon: <DashboardOutlined />,
						},
						{
							path: "/backend/setting",
							name: <FormattedMessage id="menu.settings" />,
							icon: <SettingOutlined />,
							children: [
								{
									path: "/backend/settings/account",
									name: <FormattedMessage id="menu.settings.account" />,
								},
							],
						},
						{
							component: "404",
						},
					],
				},
			}
		}
	} else {
		login()
		return null
	}

	const defaultFooterDom = (
		<DefaultFooter
			copyright={`2021 With ❤ By Maad`}
			links={[
				{
					key: "Website",
					title: (
						<GlobalOutlined style={{ fontSize: "14px", color: "#001529" }} />
					),
					href: "https://maad.dev",
					blankTarget: true,
				},
				{
					key: "Facebook",
					title: (
						<FacebookFilled style={{ fontSize: "14px", color: "#001529" }} />
					),
					href: "https://www.facebook.com/maaddev",
					blankTarget: true,
				},
				{
					key: "Github",
					title: (
						<GithubOutlined style={{ fontSize: "14px", color: "#001529" }} />
					),
					href: "https://github.com/maad-dev",
					blankTarget: true,
				},
			]}
		/>
	)

	return (
		<ThemeContext.Consumer>
			{({ currentLang, currentLocale, currentMessage }) => (
				<IntlProvider
					locale={currentLocale}
					messages={messagesMap[currentMessage]}
				>
					<ConfigProvider locale={intlMap[currentLang]}>
						<ProLayout
							logo={
								jsonData && jsonData["logo-image"]
									? jsonData["logo-image"]
									: logo
							}
							title={
								jsonData && jsonData["logo-text"]
									? jsonData["logo-text"]
									: "Modern Backend"
							}
							loading={false}
							siderWidth={jsonData ? jsonData["sider-width"] : 240}
							{...defaultProps}
							onMenuHeaderClick={() => navigate("/")}
							menuItemRender={(menuItemProps, defaultDom) => {
								if (menuItemProps.isUrl || !menuItemProps.path) {
									return defaultDom
								}

								return <Link to={menuItemProps.path}>{defaultDom}</Link>
							}}
							breadcrumbRender={(routers = []) => [
								{
									path: "/",
									breadcrumbName: <FormattedMessage id="menu.home" />,
								},
								...routers,
							]}
							itemRender={(route, params, routes, paths) => {
								const first = routes.indexOf(route) === 0
								return first ? (
									<Link to="/">{route.breadcrumbName}</Link>
								) : (
									<span>{route.breadcrumbName}</span>
								)
							}}
							footerRender={() => defaultFooterDom}
							rightContentRender={() => {
								return user ? (
									<>
										<Dropdown overlay={rightMenu}>
											<a
												className="userLinkWrapper"
												href="#none"
												onClick={(e) => e.preventDefault()}
											>
												<Avatar
													size={24}
													icon={<UserOutlined />}
													style={{
														color: "#f56a00",
														backgroundColor: "#fde3cf",
													}}
												/>
												<span className="nameOrEmail">
													{user.user_metadata.full_name
														? user.user_metadata.full_name
														: user.email}
												</span>
												<DownOutlined />
											</a>
										</Dropdown>
										<LangSwitcher />
									</>
								) : (
									<Avatar size={24}>?</Avatar>
								)
							}}
						>
							<PageContainer>
								<Router>
									<PrivateRoute
										path="/backend/dashboard"
										component={Dashboard}
									/>
									<PrivateRoute path="/backend/pages" component={Pages} />
									<PrivateRoute path="/backend/pages/all" component={Pages} />
									<PrivateRoute
										path="/backend/pages/:slug"
										component={EditPage}
									/>
									<PrivateRoute path="/backend/posts" component={Posts} />
									<PrivateRoute path="/backend/posts/all" component={Posts} />
									<PrivateRoute
										path="/backend/posts/:slug"
										component={EditPost}
									/>
									<PrivateRoute path="/backend/posts/new" component={NewPost} />
									<PrivateRoute
										path="/backend/settings/account"
										component={SettingAccount}
									/>
									<PrivateRoute
										path="/backend/settings/languages"
										component={SettingLanguages}
									/>
									<PrivateRoute
										path="/backend/settings/menus"
										component={SettingMenus}
									/>
									<PrivateRoute path="/backend/deploy" component={Deploy} />
									<BackendPage path="/backend" />
									<NotFound path="*" />
								</Router>
							</PageContainer>
						</ProLayout>
					</ConfigProvider>
				</IntlProvider>
			)}
		</ThemeContext.Consumer>
	)
}

export default Backend
